"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.observeChainHeight = exports.getNodeInfo = exports.setPrevSnapshotBlockHeightByNetID = exports.getPrevSnapshotBlockHeight = exports.setTokenIDLskByNetID = exports.getTokenIDLsk = void 0;
const tslib_1 = require("tslib");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const client_1 = require("../client");
const constants_1 = require("../constants");
let tokenIDLsk;
let prevSnapshotBlockHeight;
const getTokenIDLsk = () => tokenIDLsk;
exports.getTokenIDLsk = getTokenIDLsk;
const setTokenIDLskByNetID = async (networkIdentifier) => {
    tokenIDLsk = constants_1.NETWORK_CONSTANT[networkIdentifier].tokenID;
};
exports.setTokenIDLskByNetID = setTokenIDLskByNetID;
const getPrevSnapshotBlockHeight = () => prevSnapshotBlockHeight;
exports.getPrevSnapshotBlockHeight = getPrevSnapshotBlockHeight;
const setPrevSnapshotBlockHeightByNetID = async (networkIdentifier) => {
    prevSnapshotBlockHeight = constants_1.NETWORK_CONSTANT[networkIdentifier].prevSnapshotBlockHeight;
};
exports.setPrevSnapshotBlockHeightByNetID = setPrevSnapshotBlockHeightByNetID;
const getNodeInfo = async (liskCorePath) => {
    const client = await (0, client_1.getAPIClient)(liskCorePath);
    const { height, finalizedHeight } = await client.node.getNodeInfo();
    return { height, finalizedHeight };
};
exports.getNodeInfo = getNodeInfo;
const secondsToHumanString = (seconds) => {
    const years = Math.floor(seconds / 31536000);
    const days = Math.floor((seconds % 31536000) / 86400);
    const hours = Math.floor(((seconds % 31536000) % 86400) / 3600);
    const minutes = Math.floor((((seconds % 31536000) % 86400) % 3600) / 60);
    const numSeconds = (((seconds % 31536000) % 86400) % 3600) % 60;
    const result = [];
    if (years > 0) {
        result.push(`${years}y`);
    }
    if (days > 0) {
        result.push(`${days}d`);
    }
    if (hours > 0) {
        result.push(`${hours}h`);
    }
    if (minutes > 0) {
        result.push(`${minutes}m`);
    }
    if (numSeconds > 0) {
        result.push(`${numSeconds}s`);
    }
    if (result.length === 0) {
        return '0';
    }
    return result.join(' ');
};
const getRemainingTime = (currentHeight, observedHeight) => secondsToHumanString((observedHeight - currentHeight) * 10);
const observeChainHeight = async (options) => {
    const observedHeight = options.height;
    const startHeight = options.isFinal
        ? (await (0, exports.getNodeInfo)(options.liskCoreV3DataPath)).finalizedHeight
        : (await (0, exports.getNodeInfo)(options.liskCoreV3DataPath)).height;
    if (startHeight >= observedHeight) {
        return startHeight;
    }
    const progress = cli_ux_1.default.progress({
        format: `${options.label}: [{bar}] {percentage}% | Remaining: {remaining}/{total} | Height: {height}/${observedHeight} | ETA: {timeLeft}`,
        fps: 2,
        synchronousUpdate: false,
        etaAsynchronousUpdate: false,
        barsize: 30,
    });
    progress.start(observedHeight - startHeight, 0, {
        timeLeft: getRemainingTime(startHeight, observedHeight),
        remaining: observedHeight - startHeight,
        height: startHeight,
    });
    await new Promise((resolve, reject) => {
        let intervalId;
        const checkHeight = async () => {
            let height;
            try {
                height = options.isFinal
                    ? (await (0, exports.getNodeInfo)(options.liskCoreV3DataPath)).finalizedHeight
                    : (await (0, exports.getNodeInfo)(options.liskCoreV3DataPath)).height;
            }
            catch (error) {
                return reject(error);
            }
            progress.update(height - startHeight, {
                timeLeft: getRemainingTime(height, observedHeight),
                remaining: observedHeight - height,
                height,
            });
            if (height >= observedHeight) {
                clearInterval(intervalId);
                return resolve(height);
            }
        };
        intervalId = setInterval(checkHeight, options.delay);
    });
    progress.stop();
    return observedHeight;
};
exports.observeChainHeight = observeChainHeight;
//# sourceMappingURL=chain.js.map