"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.copyFile = exports.write = exports.copyDir = exports.resolveAbsolutePath = exports.rmdir = exports.exists = exports.extractTarBall = void 0;
const tslib_1 = require("tslib");
const os_1 = require("os");
const tar = tslib_1.__importStar(require("tar"));
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = require("path");
const extractTarBall = async (srcFilePath, destDirPath) => new Promise((resolve, reject) => {
    if (fs_1.default.existsSync(destDirPath))
        fs_1.default.rmdirSync(destDirPath, { recursive: true });
    fs_1.default.mkdirSync(destDirPath, { recursive: true });
    const fileStream = fs_1.default.createReadStream(srcFilePath);
    fileStream.pipe(tar.extract({ cwd: destDirPath }));
    fileStream.on('error', err => reject(new Error(err)));
    fileStream.on('end', () => setTimeout(resolve.bind(null, true), 100));
});
exports.extractTarBall = extractTarBall;
const exists = async (path) => {
    try {
        await fs_1.default.promises.access(path);
        return true;
    }
    catch (_) {
        return false;
    }
};
exports.exists = exists;
const rmdir = async (directoryPath, options = {}) => new Promise((resolve, reject) => {
    fs_1.default.rmdir(directoryPath, options, err => {
        if (err)
            return reject(err);
        return resolve(true);
    });
});
exports.rmdir = rmdir;
const resolveAbsolutePath = (path) => {
    const homeDirectory = (0, os_1.homedir)();
    return homeDirectory ? path.replace(/^~(?=$|\/|\\)/, homeDirectory) : path;
};
exports.resolveAbsolutePath = resolveAbsolutePath;
const copyDir = async (src, dest) => {
    await fs_1.default.promises.mkdir(dest, { recursive: true });
    const files = await fs_1.default.promises.readdir(src, { withFileTypes: true });
    for (const fileInfo of files) {
        const srcPath = (0, path_1.join)(src, fileInfo.name);
        const destPath = (0, path_1.join)(dest, fileInfo.name);
        fileInfo.isDirectory()
            ? await (0, exports.copyDir)(srcPath, destPath)
            : await fs_1.default.promises.copyFile(srcPath, destPath);
    }
};
exports.copyDir = copyDir;
const write = async (filePath, content) => new Promise((resolve, reject) => {
    fs_1.default.writeFile(filePath, content, err => {
        if (err) {
            return reject(err);
        }
        return resolve(true);
    });
});
exports.write = write;
const copyFile = async (src, dest) => new Promise((resolve, reject) => {
    fs_1.default.copyFile(src, dest, err => {
        if (err) {
            return reject(err);
        }
        return resolve(true);
    });
});
exports.copyFile = copyFile;
//# sourceMappingURL=fs.js.map